<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class NotificationController extends Controller
{
    public function __construct()
    {}

    private function parse_date($date)
    {
        $arr_date = explode('-', $date);
        $count = count($arr_date);

        if ($count == 3) {
            return $arr_date[2] . '/' . $arr_date[1] . '/' . $arr_date[0];
        } else {
            return $date;
        }
    }

    private function parse_time($time)
    {
        if (strlen($time) == 6) {
            return $time[0] . $time[1] . ':' . $time[2] . $time[3] . ':' . $time[4] . $time[5];
        } else {
            return $time;
        }
    }

    private function make_notification($data)
    {
        $notification = [
            'id' => '',
            'title' => '',
            'fecha' => '',
            'placa' => '',
            'hora' => '',
        ];

        $notification['id'] = $data->id_historico;
        $notification['placa'] = $data->placa;
        $notification['hora'] = $this->parse_time($data->ho_inicio_alerta);
        $notification['fecha'] = $this->parse_date($data->fe_inicio_alerta);

        if ($data->id_alerta != 1) {
            $notification['title'] = $data->no_alerta;
        } else {

            $title = $data->no_alerta;

            if ($data->tipo_cerca == 1) {
                $result = DB::select('
            select * from geocerca where
            id_cerca_total = :id_cerca_total
            and
            id_vehi = :id_vehi
            limit 1
            ', ['id_cerca_total' => $data->id_cerca_total,
                    'id_vehi' => $data->id_vehi]);

                if (count($result) > 0) {
                    if ($data->estado == 'in') {
                        $title = 'Entro en ' . $result[0]->nombre_geocerca;
                    } else if ($data->estado == 'out') {
                        $title = 'Salio de ' . $result[0]->nombre_geocerca;
                    } else {
                        $title = 'Desconocido';
                    }
                }
            }

            $notification['title'] = $title;
        }

        return $notification;
    }

    public function get(Request $request, $userId)
    {
        $results = DB::table('historico_alerta')
            ->join('alerta', 'historico_alerta.id_alerta', '=', 'alerta.id_alerta')
            ->join('usuario_vehiculo', 'historico_alerta.id_vehi', '=', 'usuario_vehiculo.id_vehi')
            ->join('vehiculo', 'usuario_vehiculo.id_vehi', '=', 'vehiculo.id_vehi')
            ->join('usuario', 'usuario_vehiculo.id_usuario', '=', 'usuario.id_identi_user')
            ->where('usuario.id_identi_user', '=', $userId)
            ->where('historico_alerta.descartar', '=', false)
            ->where('historico_alerta.visto', '=', false)
            ->distinct()
            ->get();

        echo json_encode($results);

        $notifications = [];

        foreach ($results as $key => $value) {
            $notifications[] = $this->make_notification($value);
        }

        return response()->json($notifications);
    }

    public function patch(Request $request, $userId, $notificationId)
    {

        $data = $request->all();

        if (!empty($data)) {
            DB::table('historico_alerta')
                ->where('id_historico', '=', $notificationId)
                ->update($data);
        }

        return response()->json(['status' => 200]);
    }

    public function delete(Request $request, $userId, $notificationId)
    {

        DB::table('historico_alerta')
            ->where('id_historico', '=', $notificationId)
            ->update(['descartar' => true]);

        return response()->json(['status' => 200]);
    }

    public function post(Request $request, $userId)
    {
        $data = [];

        $request->has("api_token") ? $data["api_token"] = $request->input("api_token") : null;
        $request->has("device_token") ? $data["device_token"] = $request->input("device_token") : null;

        if (!empty($data)) {
            DB::table('usuario')
                ->where('id_usuario', '=', $userId)
                ->update($data);

        }

        return response()->json(['status' => 200]);
    }

}
